@@ -162,7 +162,7 @@ public:
 
     for (const auto& point : cvfh_signatures.points) {
       pcl::PointCloud<FeatureT> vfh_signature;
-      vfh_signature.points.resize(1);
+      vfh_signature.resize(1);
       vfh_signature.width = vfh_signature.height = 1;
       for (int d = 0; d < 308; ++d)
         vfh_signature[0].histogram[d] = point.histogram[d];
