@@ -293,6 +293,8 @@ pcl::rec_3d_framework::LocalRecognitionPipeline<Distance, PointInT, FeatureT>::
         oh.feature_distances_ = feat_dist;
         object_hypotheses[oh.model_.id_] = oh;
       }
+      delete[] indices.ptr();
+      delete[] distances.ptr();
     }
   }
 
@@ -369,7 +371,6 @@ pcl::rec_3d_framework::LocalRecognitionPipeline<Distance, PointInT, FeatureT>::
 
     // clang-format off
 #pragma omp parallel for \
-  default(none) \
   shared(cloud_voxelized_icp) \
   schedule(dynamic,1) \
   num_threads(omp_get_num_procs())
