@@ -19,8 +19,8 @@
 #include <pcl/surface/gp3.h>
 #include <pcl/surface/marching_cubes_hoppe.h>
 #include <pcl/visualization/pcl_visualizer.h>
-#include <pcl/ModelCoefficients.h>
 #include <pcl/memory.h> // for pcl::dynamic_pointer_cast
+#include <pcl/ModelCoefficients.h>
 
 #include <string>
 #include <vector>
@@ -324,7 +324,7 @@ ICCVTutorial<FeatureType>::findCorrespondences(
 
   // Find the index of the best match for each keypoint, and store it in
   // "correspondences_out"
-  const int k = 1;
+  constexpr int k = 1;
   pcl::Indices k_indices(k);
   std::vector<float> k_squared_distances(k);
   for (int i = 0; i < static_cast<int>(source->size()); ++i) {
