@@ -39,7 +39,10 @@
  */
 
 #include <pcl/apps/manual_registration.h>
+#include <pcl/apps/pcl_viewer_dialog.h>
+#include <pcl/filters/voxel_grid.h>
 #include <pcl/io/pcd_io.h> // for loadPCDFile
+#include <pcl/registration/gicp.h>
 
 #include <QApplication>
 #include <QEvent>
@@ -55,20 +58,17 @@
 
 #include <vtkCamera.h>
 #include <vtkGenericOpenGLRenderWindow.h>
-#include <vtkRenderWindow.h>
 #include <vtkRendererCollection.h>
+#include <vtkRenderWindow.h>
 
 using namespace pcl;
+using namespace pcl::visualization;
+using std::string;
+using std::to_string;
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////
-ManualRegistration::ManualRegistration()
+ManualRegistration::ManualRegistration(float voxel_size) : voxel_size_(voxel_size)
 {
-  // Create a timer
-  vis_timer_ = new QTimer(this);
-  vis_timer_->start(5); // 5ms
-
-  connect(vis_timer_, SIGNAL(timeout()), this, SLOT(timeoutSlot()));
-
   ui_ = new Ui::MainWindow;
   ui_->setupUi(this);
 
@@ -91,7 +91,7 @@ ManualRegistration::ManualRegistration()
   vis_src_->getInteractorStyle()->setKeyboardModifier(
       pcl::visualization::INTERACTOR_KB_MOD_SHIFT);
 
-  vis_src_->registerPointPickingCallback(&ManualRegistration::SourcePointPickCallback,
+  vis_src_->registerPointPickingCallback(&ManualRegistration::SrcPointPickCallback,
                                          *this);
 
   // Set up the destination window
@@ -133,15 +133,10 @@ ManualRegistration::ManualRegistration()
           this,
           SLOT(applyTransformPressed()));
   connect(ui_->refineButton, SIGNAL(clicked()), this, SLOT(refinePressed()));
-  connect(ui_->undoButton, SIGNAL(clicked()), this, SLOT(undoPressed()));
-  connect(ui_->safeButton, SIGNAL(clicked()), this, SLOT(safePressed()));
-
-  cloud_src_modified_ = true; // first iteration is always a new pointcloud
-  cloud_dst_modified_ = true;
 }
 
 void
-ManualRegistration::SourcePointPickCallback(
+ManualRegistration::SrcPointPickCallback(
     const pcl::visualization::PointPickingEvent& event, void*)
 {
   // Check to see if we got a valid point. Early exit.
@@ -186,6 +181,15 @@ ManualRegistration::confirmSrcPointPressed()
     PCL_INFO("Selected %zu source points\n", static_cast<std::size_t>(src_pc_.size()));
     src_point_selected_ = false;
     src_pc_.width = src_pc_.size();
+    const string annotation = "marker-" + to_string(annotations_src_.size());
+    vis_src_->addSphere(src_point_, 0.02, annotation);
+    vis_src_->setShapeRenderingProperties(PCL_VISUALIZER_OPACITY, 0.2, annotation);
+    vis_src_->setShapeRenderingProperties(
+        PCL_VISUALIZER_COLOR, 0.5, 0.25, 0.25, annotation);
+    vis_src_->getShapeActorMap()->at(annotation)->SetPickable(false);
+    annotations_src_.emplace(annotation);
+
+    refreshView();
   }
   else {
     PCL_INFO("Please select a point in the source window first\n");
@@ -201,6 +205,16 @@ ManualRegistration::confirmDstPointPressed()
              static_cast<std::size_t>(dst_pc_.size()));
     dst_point_selected_ = false;
     dst_pc_.width = dst_pc_.size();
+
+    const string annotation = "marker-" + std::to_string(annotations_dst_.size());
+    vis_dst_->addSphere(dst_point_, 0.02, annotation);
+    vis_dst_->setShapeRenderingProperties(PCL_VISUALIZER_OPACITY, 0.2, annotation);
+    vis_dst_->setShapeRenderingProperties(
+        PCL_VISUALIZER_COLOR, 0.5, 0.25, 0.25, annotation);
+    vis_dst_->getShapeActorMap()->at(annotation)->SetPickable(false);
+    annotations_dst_.emplace(annotation);
+
+    refreshView();
   }
   else {
     PCL_INFO("Please select a point in the destination window first\n");
@@ -216,12 +230,13 @@ ManualRegistration::calculatePressed()
   }
   pcl::registration::TransformationEstimationSVD<pcl::PointXYZ, pcl::PointXYZ> tfe;
   tfe.estimateRigidTransformation(src_pc_, dst_pc_, transform_);
-  std::cout << "Transform : " << std::endl << transform_ << std::endl;
+  PCL_INFO_STREAM("Calculated transform:\n" << transform_ << std::endl);
 }
 
 void
 ManualRegistration::clearPressed()
 {
+  PCL_INFO("Clearing points.");
   dst_point_selected_ = false;
   src_point_selected_ = false;
   src_pc_.clear();
@@ -230,6 +245,18 @@ ManualRegistration::clearPressed()
   src_pc_.width = 0;
   dst_pc_.height = 1;
   dst_pc_.width = 0;
+
+  for (const string& annotation : annotations_src_) {
+    vis_src_->removeShape(annotation);
+  }
+  annotations_src_.clear();
+
+  for (const string& annotation : annotations_dst_) {
+    vis_dst_->removeShape(annotation);
+  }
+  annotations_dst_.clear();
+
+  refreshView();
 }
 
 void
@@ -269,38 +296,42 @@ ManualRegistration::orthoChanged(int state)
 // TODO
 void
 ManualRegistration::applyTransformPressed()
-{}
+{
+  PCLViewerDialog* diag = new PCLViewerDialog(this);
+  diag->setModal(true);
+  diag->setGeometry(this->x(), this->y(), this->width(), this->height());
+  diag->setPointClouds(cloud_src_, cloud_dst_, Eigen::Affine3f(transform_));
+  diag->show();
+}
 
 void
 ManualRegistration::refinePressed()
-{}
-
-void
-ManualRegistration::undoPressed()
-{}
-
-void
-ManualRegistration::safePressed()
-{}
-
-void
-ManualRegistration::timeoutSlot()
 {
-  if (cloud_src_present_ && cloud_src_modified_) {
-    if (!vis_src_->updatePointCloud(cloud_src_, "cloud_src_")) {
-      vis_src_->addPointCloud(cloud_src_, "cloud_src_");
-      vis_src_->resetCameraViewpoint("cloud_src_");
-    }
-    cloud_src_modified_ = false;
-  }
-  if (cloud_dst_present_ && cloud_dst_modified_) {
-    if (!vis_dst_->updatePointCloud(cloud_dst_, "cloud_dst_")) {
-      vis_dst_->addPointCloud(cloud_dst_, "cloud_dst_");
-      vis_dst_->resetCameraViewpoint("cloud_dst_");
-    }
-    cloud_dst_modified_ = false;
-  }
-  refreshView();
+  PCL_INFO("Refining transform ...\n");
+  VoxelGrid<PointT> grid_filter;
+  grid_filter.setLeafSize(voxel_size_, voxel_size_, voxel_size_);
+  PointCloud<PointT>::Ptr src_copy{new PointCloud<PointT>(*cloud_src_)};
+  PointCloud<PointT>::Ptr dst_copy{new PointCloud<PointT>(*cloud_dst_)};
+  grid_filter.setInputCloud(src_copy);
+  grid_filter.filter(*src_copy);
+  grid_filter.setInputCloud(dst_copy);
+  grid_filter.filter(*dst_copy);
+
+  using ICP = GeneralizedIterativeClosestPoint<PointT, PointT>;
+  ICP::Ptr icp = pcl::make_shared<ICP>();
+  icp->setInputSource(src_copy);
+  icp->setInputTarget(dst_copy);
+
+  icp->setMaximumIterations(100);
+  icp->setMaxCorrespondenceDistance(0.3);
+  icp->setEuclideanFitnessEpsilon(0.01);
+  icp->setTransformationEpsilon(0.01);
+  icp->setTransformationRotationEpsilon(0.01);
+  PointCloud<PointT>::Ptr aligned{new PointCloud<PointT>};
+  icp->align(*aligned, transform_);
+  transform_ = icp->getFinalTransformation();
+
+  PCL_INFO_STREAM("Calculated transform:\n" << transform_ << std::endl);
 }
 
 void
@@ -308,8 +339,10 @@ ManualRegistration::refreshView()
 {
 #if VTK_MAJOR_VERSION > 8
   ui_->qvtk_widget_dst->renderWindow()->Render();
+  ui_->qvtk_widget_src->renderWindow()->Render();
 #else
   ui_->qvtk_widget_dst->update();
+  ui_->qvtk_widget_src->update();
 #endif // VTK_MAJOR_VERSION > 8
 }
 
@@ -319,6 +352,7 @@ print_usage()
   PCL_INFO("manual_registration cloud1.pcd cloud2.pcd\n");
   PCL_INFO("\t cloud1 \t source cloud\n");
   PCL_INFO("\t cloud2 \t destination cloud\n");
+  PCL_INFO("\t voxel_size \t voxel size for automatic refinement\n");
 }
 
 int
@@ -329,31 +363,30 @@ main(int argc, char** argv)
 #endif
   QApplication app(argc, argv);
 
-  pcl::PointCloud<pcl::PointXYZRGBA>::Ptr cloud_src(
-      new pcl::PointCloud<pcl::PointXYZRGBA>);
-  pcl::PointCloud<pcl::PointXYZRGBA>::Ptr cloud_dst(
-      new pcl::PointCloud<pcl::PointXYZRGBA>);
+  pcl::PointCloud<PointT>::Ptr cloud_src(new pcl::PointCloud<PointT>);
+  pcl::PointCloud<PointT>::Ptr cloud_dst(new pcl::PointCloud<PointT>);
 
-  if (argc < 3) {
+  if (argc < 4) {
     PCL_ERROR("Incorrect usage\n");
     print_usage();
+    return -1;
   }
 
   // TODO do this with PCL console
-  if (pcl::io::loadPCDFile<pcl::PointXYZRGBA>(argv[1], *cloud_src) ==
-      -1) //* load the file
+  if (pcl::io::loadPCDFile<PointT>(argv[1], *cloud_src) == -1) //* load the file
   {
     PCL_ERROR("Couldn't read file %s \n", argv[1]);
     return -1;
   }
-  if (pcl::io::loadPCDFile<pcl::PointXYZRGBA>(argv[2], *cloud_dst) ==
-      -1) //* load the file
+  if (pcl::io::loadPCDFile<PointT>(argv[2], *cloud_dst) == -1) //* load the file
   {
     PCL_ERROR("Couldn't read file %s \n", argv[2]);
     return -1;
   }
 
-  ManualRegistration man_reg;
+  const float voxel_size = std::atof(argv[3]);
+
+  ManualRegistration man_reg(voxel_size);
 
   man_reg.setSrcCloud(cloud_src);
   man_reg.setDstCloud(cloud_dst);
