@@ -89,7 +89,7 @@ computeRoots (const Matrix& m, Roots& roots)
     computeRoots2 (c2, c1, roots);
   else
   {
-    const Scalar s_inv3 = Scalar (1.0 / 3.0);
+    constexpr Scalar s_inv3 = Scalar(1.0 / 3.0);
     const Scalar s_sqrt3 = std::sqrt (Scalar (3.0));
     // Construct the parameters used in classifying the roots of the equation
     // and in solving the equation for the roots in closed form.
@@ -285,8 +285,7 @@ getLargest3x3Eigenvector (const Matrix scaledMatrix)
 
   Index index;
   const Scalar length = len.maxCoeff (&index);  // <- first evaluation
-  return EigenVector<Vector, Scalar> {crossProduct.row (index) / length,
-                                      length};
+  return {crossProduct.row (index) / length, length};
 }
 
 }  // namespace detail
