@@ -158,6 +158,24 @@ namespace pcl
         delete [] temp;
       }
 
+      void
+      vectorize (const PointT &p, float* out) const
+      {
+        copyToFloatArray (p, out);
+        if (!alpha_.empty ())
+          for (int i = 0; i < nr_dimensions_; ++i)
+            out[i] *= alpha_[i];
+      }
+
+      void
+      vectorize (const PointT &p, std::vector<float> &out) const
+      {
+        copyToFloatArray (p, out.data());
+        if (!alpha_.empty ())
+          for (int i = 0; i < nr_dimensions_; ++i)
+            out[i] *= alpha_[i];
+      }
+
       /** \brief Set the rescale values to use when vectorizing points
         * \param[in] rescale_array The array/vector of rescale values.  Can be of any type that implements the [] operator.
         */
@@ -245,12 +263,12 @@ namespace pcl
       using Pod = typename traits::POD<PointDefault>::type;
 
       NdCopyPointFunctor (const PointDefault &p1, float * p2)
-        : p1_ (reinterpret_cast<const Pod&>(p1)), p2_ (p2), f_idx_ (0) { }
+        : p1_ (reinterpret_cast<const Pod&>(p1)), p2_ (p2) {}
 
       template<typename Key> inline void operator() ()
       {
         using FieldT = typename pcl::traits::datatype<PointDefault, Key>::type;
-        const int NrDims = pcl::traits::datatype<PointDefault, Key>::size;
+        constexpr int NrDims = pcl::traits::datatype<PointDefault, Key>::size;
         Helper<Key, FieldT, NrDims>::copyPoint (p1_, p2_, f_idx_);
       }
 
@@ -285,7 +303,7 @@ namespace pcl
     private:
       const Pod &p1_;
       float * p2_;
-      int f_idx_;
+      int f_idx_{0};
     };
 
     public:
