@@ -2,7 +2,7 @@
 
 #include "typedefs.h"
 
-#include <pcl/io/io.h>
+#include <pcl/common/io.h>
 #include <pcl/features/normal_3d.h>
 #include <pcl/keypoints/sift_keypoint.h>
 #include <pcl/features/fpfh.h>
