@@ -18,24 +18,24 @@ public:
   std::vector<pcl::Vertices> faces;
 };
 
-typedef boost::shared_ptr<Mesh> MeshPtr;
+using MeshPtr = std::shared_ptr<Mesh>;
 
 PointCloudPtr
-smoothPointCloud (const PointCloudPtr & input, float radius, int polynomial_order)
+smoothPointCloud (const PointCloudPtr & /*input*/, float /*radius*/, int /*polynomial_order*/)
 {
   PointCloudPtr output (new PointCloud);
   return (output);
 }
 
 SurfaceElementsPtr
-computeSurfaceElements (const PointCloudPtr & input, float radius, int polynomial_order)
+computeSurfaceElements (const PointCloudPtr & /*input*/, float /*radius*/, int /*polynomial_order*/)
 {
   SurfaceElementsPtr surfels (new SurfaceElements);
   return (surfels);
 }
 
 MeshPtr
-computeConvexHull (const PointCloudPtr & input)
+computeConvexHull (const PointCloudPtr & /*input*/)
 {
   MeshPtr output (new Mesh);
   return (output);
@@ -43,15 +43,15 @@ computeConvexHull (const PointCloudPtr & input)
 
 
 MeshPtr
-computeConcaveHull (const PointCloudPtr & input, float alpha)
+computeConcaveHull (const PointCloudPtr & /*input*/, float /*alpha*/)
 {
   MeshPtr output (new Mesh);
   return (output);
 }
 
 pcl::PolygonMesh::Ptr
-greedyTriangulation (const SurfaceElementsPtr & surfels, float radius, float mu, int max_nearest_neighbors, 
-                     float max_surface_angle, float min_angle, float max_angle)
+greedyTriangulation (const SurfaceElementsPtr & /*surfels*/, float /*radius*/, float /*mu*/, int /*max_nearest_neighbors*/, 
+                     float /*max_surface_angle*/, float /*min_angle*/, float /*max_angle*/)
 
 {
   pcl::PolygonMesh::Ptr output (new pcl::PolygonMesh);
@@ -60,7 +60,7 @@ greedyTriangulation (const SurfaceElementsPtr & surfels, float radius, float mu,
 
 
 pcl::PolygonMesh::Ptr
-marchingCubesTriangulation (const SurfaceElementsPtr & surfels, float leaf_size, float iso_level)
+marchingCubesTriangulation (const SurfaceElementsPtr & /*surfels*/, float /*leaf_size*/, float /*iso_level*/)
 {
   pcl::PolygonMesh::Ptr output (new pcl::PolygonMesh);
   return (output);
