@@ -37,11 +37,8 @@
  *
  */
 
-// STL
 #include <iostream>
 
-// PCL
-#include <pcl/point_types.h>
 #include <pcl/filters/extract_indices.h>
 
 int
@@ -58,18 +55,18 @@ main (int, char**)
     cloud->push_back (p);
   }
 
-  std::cout << "Cloud has " << cloud->points.size () << " points." << std::endl;
+  std::cout << "Cloud has " << cloud->size () << " points." << std::endl;
 
   pcl::PointIndices indices;
   indices.indices.push_back (0);
   indices.indices.push_back (2);
 
   pcl::ExtractIndices<PointType> extract_indices;
-  extract_indices.setIndices (boost::make_shared<const pcl::PointIndices> (indices));
+  extract_indices.setIndices (pcl::make_shared<const pcl::PointIndices> (indices));
   extract_indices.setInputCloud (cloud);
   pcl::PointCloud<pcl::PointXYZ>::Ptr output (new pcl::PointCloud<pcl::PointXYZ>);
   extract_indices.filter (*output);
 
-  std::cout << "Output has " << output->points.size () << " points." << std::endl;
+  std::cout << "Output has " << output->size () << " points." << std::endl;
   return (0);
 }
