@@ -77,39 +77,39 @@ keyboardEventOccurred (const pcl::visualization::KeyboardEvent& event_arg,
   if (event_arg.keyUp ())
     switch (key)
     {
-      case (int) '1':
+      case static_cast<int>('1'):
         show_normals = !show_normals;
         normals_changed = true;
         break;
-      case (int) '2':
+      case static_cast<int>('2'):
         show_adjacency = !show_adjacency;
         break;
-      case (int) '3':
+      case static_cast<int>('3'):
         show_supervoxels = !show_supervoxels;
         break;
-      case (int) '4':
+      case static_cast<int>('4'):
         show_segmentation = !show_segmentation;
         break;
-      case (int) '5':
+      case static_cast<int>('5'):
         normals_scale *= 1.25;
         normals_changed = true;
         break;
-      case (int) '6':
+      case static_cast<int>('6'):
         normals_scale *= 0.8;
         normals_changed = true;
         break;
-      case (int) '7':
+      case static_cast<int>('7'):
         line_width += 0.5;
         line_changed = true;
         break;
-      case (int) '8':
+      case static_cast<int>('8'):
         if (line_width <= 1)
           break;
         line_width -= 0.5;
         line_changed = true;
         break;
-      case (int) 'd':
-      case (int) 'D':
+      case static_cast<int>('d'):
+      case static_cast<int>('D'):
         show_help = !show_help;
         break;
       default:
