@@ -42,7 +42,6 @@
 #define PCL_FEATURES_IMPL_CPPF_H_
 
 #include <pcl/features/cppf.h>
-#include <pcl/features/pfh.h>
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointInT, typename PointNT, typename PointOutT>
@@ -110,7 +109,7 @@ pcl::CPPFEstimation<PointInT, PointNT, PointOutT>::computeFeature (PointCloudOut
         output.is_dense = false;
       }
 
-      output.points.push_back (p);
+      output.push_back (p);
     }
   }
   // overwrite the sizes done by Feature::initCompute ()
