@@ -49,10 +49,7 @@ namespace pcl
 {
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////
-RangeImageBorderExtractor::RangeImageBorderExtractor(const RangeImage* range_image) :
-  range_image_(range_image), range_image_size_during_extraction_(0),
-  surface_structure_(nullptr), border_descriptions_(nullptr), shadow_border_informations_(nullptr), border_directions_(nullptr),
-  surface_change_scores_(nullptr), surface_change_directions_(nullptr)
+RangeImageBorderExtractor::RangeImageBorderExtractor(const RangeImage* range_image) : range_image_(range_image)
 {
 }
 
@@ -616,9 +613,9 @@ RangeImageBorderExtractor::blurSurfaceChanges ()
 
   auto* blurred_directions = new Eigen::Vector3f[range_image.width*range_image.height];
   float* blurred_scores = new float[range_image.width*range_image.height];
-  for (int y=0; y<int(range_image.height); ++y)
+  for (int y=0; y<static_cast<int>(range_image.height); ++y)
   {
-    for (int x=0; x<int(range_image.width); ++x)
+    for (int x=0; x<static_cast<int>(range_image.width); ++x)
     {
       int index = y*range_image.width + x;
       Eigen::Vector3f& new_point = blurred_directions[index];
