@@ -189,7 +189,7 @@ pcl::VoxelGridLabel::applyFilter (PointCloud &output)
 
   // Second pass: sort the index_vector vector using value representing target cell as index
   // in effect all points belonging to the same output cell will be next to each other
-  std::sort (index_vector.begin (), index_vector.end (), std::less<cloud_point_index_idx> ());
+  std::sort (index_vector.begin (), index_vector.end (), std::less<> ());
 
   // Third pass: count output cells
   // we need to skip all the same, adjacenent idx values
