@@ -48,6 +48,7 @@
 #include <pcl/pcl_macros.h>
 #include <pcl/point_cloud.h>
 
+#include <cassert>
 #include <type_traits>
 #include <vector>
 
@@ -183,7 +184,7 @@ public:
   {
     vertices_.push_back(Vertex());
     this->addData(vertex_data_cloud_, vertex_data, HasVertexData());
-    return (VertexIndex(static_cast<int>(this->sizeVertices() - 1)));
+    return (static_cast<VertexIndex>(this->sizeVertices() - 1));
   }
 
   /**
@@ -323,25 +324,28 @@ public:
     }
 
     // Adjust the indices
-    for (auto it = vertices_.begin(); it != vertices_.end(); ++it) {
-      if (it->idx_outgoing_half_edge_.isValid()) {
-        it->idx_outgoing_half_edge_ =
-            new_half_edge_indices[it->idx_outgoing_half_edge_.get()];
+    for (auto& vertex : vertices_) {
+      if (vertex.idx_outgoing_half_edge_.isValid()) {
+        vertex.idx_outgoing_half_edge_ =
+            new_half_edge_indices[vertex.idx_outgoing_half_edge_.get()];
       }
     }
 
-    for (auto it = half_edges_.begin(); it != half_edges_.end(); ++it) {
-      it->idx_terminating_vertex_ =
-          new_vertex_indices[it->idx_terminating_vertex_.get()];
-      it->idx_next_half_edge_ = new_half_edge_indices[it->idx_next_half_edge_.get()];
-      it->idx_prev_half_edge_ = new_half_edge_indices[it->idx_prev_half_edge_.get()];
-      if (it->idx_face_.isValid()) {
-        it->idx_face_ = new_face_indices[it->idx_face_.get()];
+    for (auto& half_edge : half_edges_) {
+      half_edge.idx_terminating_vertex_ =
+          new_vertex_indices[half_edge.idx_terminating_vertex_.get()];
+      half_edge.idx_next_half_edge_ =
+          new_half_edge_indices[half_edge.idx_next_half_edge_.get()];
+      half_edge.idx_prev_half_edge_ =
+          new_half_edge_indices[half_edge.idx_prev_half_edge_.get()];
+      if (half_edge.idx_face_.isValid()) {
+        half_edge.idx_face_ = new_face_indices[half_edge.idx_face_.get()];
       }
     }
 
-    for (auto it = faces_.begin(); it != faces_.end(); ++it) {
-      it->idx_inner_half_edge_ = new_half_edge_indices[it->idx_inner_half_edge_.get()];
+    for (auto& face : faces_) {
+      face.idx_inner_half_edge_ =
+          new_half_edge_indices[face.idx_inner_half_edge_.get()];
     }
   }
 
@@ -637,29 +641,32 @@ public:
   inline bool
   isValid(const VertexIndex& idx_vertex) const
   {
-    return (idx_vertex >= VertexIndex(0) &&
-            idx_vertex < VertexIndex(int(vertices_.size())));
+    return (idx_vertex >= static_cast<VertexIndex>(0) &&
+            idx_vertex < static_cast<VertexIndex>(vertices_.size()));
   }
 
   /** \brief Check if the given half-edge index is a valid index into the mesh.  */
   inline bool
   isValid(const HalfEdgeIndex& idx_he) const
   {
-    return (idx_he >= HalfEdgeIndex(0) && idx_he < HalfEdgeIndex(half_edges_.size()));
+    return (idx_he >= static_cast<HalfEdgeIndex>(0) &&
+            idx_he < static_cast<HalfEdgeIndex>(half_edges_.size()));
   }
 
   /** \brief Check if the given edge index is a valid index into the mesh. */
   inline bool
   isValid(const EdgeIndex& idx_edge) const
   {
-    return (idx_edge >= EdgeIndex(0) && idx_edge < EdgeIndex(half_edges_.size() / 2));
+    return (idx_edge >= static_cast<EdgeIndex>(0) &&
+            idx_edge < static_cast<EdgeIndex>(half_edges_.size() / 2));
   }
 
   /** \brief Check if the given face index is a valid index into the mesh.  */
   inline bool
   isValid(const FaceIndex& idx_face) const
   {
-    return (idx_face >= FaceIndex(0) && idx_face < FaceIndex(faces_.size()));
+    return (idx_face >= static_cast<FaceIndex>(0) &&
+            idx_face < static_cast<FaceIndex>(faces_.size()));
   }
 
   ////////////////////////////////////////////////////////////////////////
@@ -727,7 +734,7 @@ public:
     return (this->isBoundary(this->getOutgoingHalfEdgeIndex(idx_vertex)));
   }
 
-  /** \brief Check if the given half-edge lies on the bounddary. */
+  /** \brief Check if the given half-edge lies on the boundary. */
   inline bool
   isBoundary(const HalfEdgeIndex& idx_he) const
   {
@@ -1088,7 +1095,7 @@ public:
              &vertex_data <= &vertex_data_cloud_.back());
       return (VertexIndex(std::distance(&vertex_data_cloud_.front(), &vertex_data)));
     }
-    return (VertexIndex());
+    return {};
   }
 
   /** \brief Get the index associated to the given half-edge data. */
@@ -1101,7 +1108,7 @@ public:
       return (HalfEdgeIndex(
           std::distance(&half_edge_data_cloud_.front(), &half_edge_data)));
     }
-    return (HalfEdgeIndex());
+    return {};
   }
 
   /** \brief Get the index associated to the given edge data. */
@@ -1113,7 +1120,7 @@ public:
              &edge_data <= &edge_data_cloud_.back());
       return (EdgeIndex(std::distance(&edge_data_cloud_.front(), &edge_data)));
     }
-    return (EdgeIndex());
+    return {};
   }
 
   /** \brief Get the index associated to the given face data. */
@@ -1125,7 +1132,7 @@ public:
              &face_data <= &face_data_cloud_.back());
       return (FaceIndex(std::distance(&face_data_cloud_.front(), &face_data)));
     }
-    return (FaceIndex());
+    return {};
   }
 
 protected:
@@ -1159,7 +1166,7 @@ protected:
   {
     const int n = static_cast<int>(vertices.size());
     if (n < 3)
-      return (FaceIndex());
+      return {};
 
     // Check for topological errors
     inner_he_.resize(n);
@@ -1172,7 +1179,7 @@ protected:
                                 inner_he_[i],
                                 is_new_[i],
                                 IsManifold())) {
-        return (FaceIndex());
+        return {};
       }
     }
     for (int i = 0; i < n; ++i) {
@@ -1185,7 +1192,7 @@ protected:
                                 make_adjacent_[i],
                                 free_he_[i],
                                 IsManifold())) {
-        return (FaceIndex());
+        return {};
       }
     }
 
@@ -1248,7 +1255,7 @@ protected:
     this->addData(half_edge_data_cloud_, he_data, HasHalfEdgeData());
     this->addData(edge_data_cloud_, edge_data, HasEdgeData());
 
-    return (HalfEdgeIndex(static_cast<int>(half_edges_.size() - 2)));
+    return (static_cast<HalfEdgeIndex>(half_edges_.size() - 2));
   }
 
   ////////////////////////////////////////////////////////////////////////
@@ -2167,7 +2174,7 @@ private:
   /** \brief Connectivity information for the faces. */
   Faces faces_;
 
-  // NOTE: It is MUCH faster to store these variables permamently.
+  // NOTE: It is MUCH faster to store these variables permanently.
 
   /** \brief Storage for addFaceImplBase and deleteFace. */
   HalfEdgeIndices inner_he_;
