@@ -52,15 +52,14 @@
 #include "tsdf_volume.h"
 #include "tsdf_volume.hpp"
 
-using namespace std;
 namespace pc = pcl::console;
 
 using PointT = pcl::PointXYZ;
 using VoxelT = float;
 using WeightT = short;
 
-string cloud_file  = "cloud.pcd";
-string volume_file = "tsdf_volume.dat";
+std::string cloud_file  = "cloud.pcd";
+std::string volume_file = "tsdf_volume.dat";
 
 double min_trunc_dist = 30.0f;
 
@@ -96,7 +95,7 @@ public:
 
   /** \brief Creates the TSDF volume on the GPU
    * param[in] depth depth readings from the sensor
-   * param[in] intr camaera intrinsics
+   * param[in] intr camera intrinsics
    */
   void
   createFromDepth (const pcl::device::PtrStepSz<const unsigned short> &depth, const pcl::device::Intr &intr);
@@ -179,7 +178,9 @@ DeviceVolume::getVolume (pcl::TSDFVolume<VoxelT, WeightT>::Ptr &volume)
 
   device_volume_.download (&volume_vec[0], device_volume_.cols() * sizeof(int));
 
-  #pragma omp parallel for
+  #pragma omp parallel for \
+    default(none) \
+    shared(volume, volume_vec, weights_vec)
   for(int i = 0; i < (int) volume->size(); ++i)
   {
     short2 *elem = (short2*)&volume_vec[i];
@@ -205,7 +206,7 @@ DeviceVolume::getCloud (pcl::PointCloud<pcl::PointXYZ>::Ptr &cloud)
 
   // write into point cloud structure
   device_cloud_buffer.download (cloud->points);
-  cloud->width = (int)cloud->points.size ();
+  cloud->width = cloud->size ();
   cloud->height = 1;
 
   return true;
@@ -448,7 +449,7 @@ main (int argc, char* argv[])
 
 
   // integrate depth in device volume
-  pc::print_highlight ("Converting depth map to volume ... "); std::cout << flush;
+  pc::print_highlight ("Converting depth map to volume ... "); std::cout << std::flush;
   device_volume->createFromDepth (depth, intr);
 
   // get volume from device
@@ -461,7 +462,7 @@ main (int argc, char* argv[])
 
 
   // generating TSDF cloud
-  pc::print_highlight ("Generating tsdf volume cloud ... "); std::cout << flush;
+  pc::print_highlight ("Generating tsdf volume cloud ... "); std::cout << std::flush;
   pcl::PointCloud<pcl::PointXYZI>::Ptr tsdf_cloud (new pcl::PointCloud<pcl::PointXYZI>);
   volume->convertToTsdfCloud (tsdf_cloud);
   pc::print_info ("done [%d points]\n", tsdf_cloud->size());
@@ -471,7 +472,7 @@ main (int argc, char* argv[])
   pcl::PointCloud<pcl::PointXYZ>::Ptr cloud_volume (new pcl::PointCloud<pcl::PointXYZ>);
   if (extract_cloud_volume)
   {
-    pc::print_highlight ("Generating cloud from volume ... "); std::cout << flush;
+    pc::print_highlight ("Generating cloud from volume ... "); std::cout << std::flush;
     if (!device_volume->getCloud (cloud_volume))
     {
       pc::print_error ("Cloudn't get cloud from device volume!\n");
@@ -502,7 +503,7 @@ main (int argc, char* argv[])
     pc::print_error ("Cloudn't save the volume to file %s.\n", volume_file.c_str());
 
   // TSDF point cloud
-  string tsdf_cloud_file (pcl::getFilenameWithoutExtension(volume_file) + "_cloud.pcd");
+  std::string tsdf_cloud_file (pcl::getFilenameWithoutExtension(volume_file) + "_cloud.pcd");
   pc::print_info ("Saving volume cloud to "); pc::print_value ("%s", tsdf_cloud_file.c_str()); pc::print_info (" ... ");
   if (pcl::io::savePCDFile (tsdf_cloud_file, *tsdf_cloud, true) < 0)
   {
@@ -515,7 +516,7 @@ main (int argc, char* argv[])
   // point cloud from volume
   if (extract_cloud_volume)
   {
-    string cloud_volume_file (pcl::getFilenameWithoutExtension(cloud_file) + "_from_volume.pcd");
+    std::string cloud_volume_file (pcl::getFilenameWithoutExtension(cloud_file) + "_from_volume.pcd");
     pc::print_info ("Saving cloud from volume to "); pc::print_value ("%s", cloud_volume_file.c_str()); pc::print_info (" ... ");
     if (pcl::io::savePCDFile (cloud_volume_file, *cloud_volume, true) < 0)
     {
