@@ -78,7 +78,7 @@ std::vector<std::string> getPcdFilesInDir(const std::string& directory)
 
   for(; pos != end ; ++pos)
     if (fs::is_regular_file(pos->status()) )
-      if (fs::extension(*pos) == ".pcd")
+      if (pos->path().extension().string() == ".pcd")
         result.push_back(pos->path().string());
     
   return result;  
@@ -373,7 +373,7 @@ int main(int argc, char** argv)
   if(pc::find_switch (argc, argv, "--help") || pc::find_switch (argc, argv, "-h"))
     return print_help(), 0;
   
-  // selecting GPU and prining info
+  // selecting GPU and printing info
   int device = 0;
   pc::parse_argument (argc, argv, "-gpu", device);
   pcl::gpu::setDevice (device);
