@@ -70,16 +70,12 @@ pcl::PLYReader::elementDefinitionCallback (const std::string& element_name, std:
     cloud_->point_step = 0;
     cloud_->row_step = 0;
     vertex_count_ = 0;
-    return (std::tuple<std::function<void ()>, std::function<void ()> > (
-              [this] { vertexBeginCallback (); },
-              [this] { vertexEndCallback (); }));
+    return {[this] { vertexBeginCallback(); }, [this] { vertexEndCallback(); }};
   }
   if ((element_name == "face") && polygons_)
   {
     polygons_->reserve (count);
-    return (std::tuple<std::function<void ()>, std::function<void ()> > (
-            [this] { faceBeginCallback (); },
-            [this] { faceEndCallback (); }));
+    return {[this] { faceBeginCallback(); }, [this] { faceEndCallback(); }};
   }
   if (element_name == "camera")
   {
@@ -89,9 +85,7 @@ pcl::PLYReader::elementDefinitionCallback (const std::string& element_name, std:
   if (element_name == "range_grid")
   {
     range_grid_->reserve (count);
-    return (std::tuple<std::function<void ()>, std::function<void ()> > (
-              [this] { rangeGridBeginCallback (); },
-              [this] { rangeGridEndCallback (); }));
+    return {[this] { rangeGridBeginCallback(); }, [this] { rangeGridEndCallback(); }};
   }
   return {};
 }
@@ -100,7 +94,7 @@ bool
 pcl::PLYReader::endHeaderCallback ()
 {
   cloud_->data.resize (static_cast<std::size_t>(cloud_->point_step) * cloud_->width * cloud_->height);
-  return (true);
+  return true;
 }
 
 template<typename Scalar> void
@@ -364,7 +358,7 @@ namespace pcl
         cloud_->point_step = static_cast<std::uint32_t> (std::numeric_limits<std::uint32_t>::max ());
       do_resize_ = true;
       return std::tuple<std::function<void (SizeType)>, std::function<void (ContentType)>, std::function<void ()> > (
-        std::bind (&pcl::PLYReader::vertexListPropertyBeginCallback<SizeType>, this, property_name, std::placeholders::_1),
+        [this, property_name](SizeType size) { this->vertexListPropertyBeginCallback(property_name, size); },
         [this] (ContentType value) { vertexListPropertyContentCallback (value); },
         [this] { vertexListPropertyEndCallback (); }
       );
@@ -379,16 +373,16 @@ pcl::PLYReader::vertexColorCallback (const std::string& color_name, pcl::io::ply
 {
   if ((color_name == "red") || (color_name == "diffuse_red"))
   {
-    r_ = std::int32_t (color);
+    r_ = static_cast<std::int32_t>(color);
     rgb_offset_before_ = vertex_offset_before_;
   }
   if ((color_name == "green") || (color_name == "diffuse_green"))
   {
-    g_ = std::int32_t (color);
+    g_ = static_cast<std::int32_t>(color);
   }
   if ((color_name == "blue") || (color_name == "diffuse_blue"))
   {
-    b_ = std::int32_t (color);
+    b_ = static_cast<std::int32_t>(color);
     std::int32_t rgb = r_ << 16 | g_ << 8 | b_;
     try
     {
@@ -409,7 +403,7 @@ pcl::PLYReader::vertexAlphaCallback (pcl::io::ply::uint8 alpha)
   // get anscient rgb value and store it in rgba
   rgba_ = cloud_->at<std::uint32_t>(vertex_count_, rgb_offset_before_);
   // append alpha
-  a_ = std::uint32_t (alpha);
+  a_ = static_cast<std::uint32_t>(alpha);
   rgba_ |= a_ << 24;
   // put rgba back
   cloud_->at<std::uint32_t>(vertex_count_, rgb_offset_before_) = rgba_;
@@ -568,9 +562,11 @@ pcl::PLYReader::readHeader (const std::string &file_name, pcl::PCLPointCloud2 &c
   cloud_->width = cloud_->height = 0;
   origin = Eigen::Vector4f::Zero ();
   orientation = Eigen::Quaternionf::Identity ();
+  origin_ = Eigen::Vector4f::Zero ();
+  orientation_ = Eigen::Matrix3f::Identity ();
   if (!parse (file_name))
   {
-    PCL_ERROR ("[pcl::PLYReader::read] problem parsing header!\n");
+    PCL_ERROR ("[pcl::PLYReader::readHeader] problem parsing header!\n");
     return (-1);
   }
   cloud_->row_step = cloud_->point_step * cloud_->width;
@@ -647,7 +643,7 @@ pcl::PLYReader::read (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
       }
       else
       {
-        const auto srcIdx = (*range_grid_)[r][0] * cloud_->point_step;
+        const std::size_t srcIdx = (*range_grid_)[r][0] * cloud_->point_step;
         if (srcIdx + cloud_->point_step > cloud_->data.size())
         {
           PCL_ERROR ("[pcl::PLYReader::read] invalid data index (%lu)!\n", srcIdx);
@@ -659,8 +655,8 @@ pcl::PLYReader::read (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
     cloud_->data.swap (data);
   }
 
-  orientation_ = Eigen::Quaternionf (orientation);
-  origin_ = origin;
+  orientation = Eigen::Quaternionf (orientation_);
+  origin = origin_;
 
   for (auto &field : cloud_->fields)
   {
@@ -680,6 +676,7 @@ pcl::PLYReader::read (const std::string &file_name, pcl::PolygonMesh &mesh,
                       Eigen::Vector4f &origin, Eigen::Quaternionf &orientation,
                       int &ply_version, const int offset)
 {
+  PCL_DEBUG("[pcl::PLYReader::read] Reading PolygonMesh from file: %s.\n", file_name.c_str());
   // kept only for backward compatibility
   int data_type;
   unsigned int data_idx;
@@ -746,7 +743,7 @@ pcl::PLYReader::read (const std::string &file_name, pcl::PolygonMesh &mesh,
       }
       else
       {
-        const auto srcIdx = (*range_grid_)[r][0] * cloud_->point_step;
+        const std::size_t srcIdx = (*range_grid_)[r][0] * cloud_->point_step;
         if (srcIdx + cloud_->point_step > cloud_->data.size())
         {
           PCL_ERROR ("[pcl::PLYReader::read] invalid data index (%lu)!\n", srcIdx);
@@ -758,8 +755,8 @@ pcl::PLYReader::read (const std::string &file_name, pcl::PolygonMesh &mesh,
     cloud_->data.swap (data);
   }
 
-  orientation_ = Eigen::Quaternionf (orientation);
-  origin_ = origin;
+  orientation = Eigen::Quaternionf (orientation_);
+  origin = origin_;
 
   for (auto &field : cloud_->fields)
   {
@@ -793,6 +790,7 @@ pcl::PLYWriter::generateHeader (const pcl::PCLPointCloud2 &cloud,
                                 int valid_points)
 {
   std::ostringstream oss;
+  oss.imbue (std::locale::classic ()); // mostly to make sure that no thousands separator is printed
   // Begin header
   oss << "ply";
   if (!binary)
@@ -1536,13 +1534,13 @@ pcl::io::savePLYFile (const std::string &file_name, const pcl::PolygonMesh &mesh
 
       {
         const auto& color = mesh.cloud.at<RGB>(i, mesh.cloud.fields[d].offset);
-        fs << int (color.r) << " " << int (color.g) << " " << int (color.b) << " ";
+        fs << static_cast<int>(color.r) << " " << static_cast<int>(color.g) << " " << static_cast<int>(color.b) << " ";
       }
       else if ((mesh.cloud.fields[d].datatype == pcl::PCLPointField::UINT32) &&
                (mesh.cloud.fields[d].name == "rgba"))
       {
         const auto& color = mesh.cloud.at<RGB>(i, mesh.cloud.fields[d].offset);
-        fs << int (color.r) << " " << int (color.g) << " " << int (color.b) << " " << int (color.a) << " ";
+        fs << static_cast<int>(color.r) << " " << static_cast<int>(color.g) << " " << static_cast<int>(color.b) << " " << static_cast<int>(color.a) << " ";
       }
       else if ((mesh.cloud.fields[d].datatype == pcl::PCLPointField::FLOAT32) && (
                 mesh.cloud.fields[d].name == "normal_x" ||
