@@ -83,7 +83,7 @@ pcl::TimGrabber::updateLookupTables () {
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 bool
 pcl::TimGrabber::isValidPacket () const {
-  return received_packet_.data ()[length_-1] == '\03';
+  return received_packet_[length_-1] == '\03';
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////
@@ -215,7 +215,7 @@ pcl::TimGrabber::isRunning () const
 std::string
 pcl::TimGrabber::getName () const
 {
-  return (std::string ("Sick Tim Grabber"));
+  return {"Sick Tim Grabber"};
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////
