@@ -76,10 +76,8 @@ namespace pcl
         BaseClass (), 
         search_method_surface_ (),
         surface_ (), 
-        tree_ (), 
-        search_parameter_ (0), 
-        search_radius_ (0), 
-        k_ (0) 
+        tree_ () 
+        
       {};
       
       /** \brief Empty destructor */
@@ -181,13 +179,13 @@ namespace pcl
       KdTreePtr tree_;
 
       /** \brief The actual search parameter (casted from either \a search_radius_ or \a k_). */
-      double search_parameter_;
+      double search_parameter_{0.0};
 
       /** \brief The nearest neighbors search radius for each point. */
-      double search_radius_;
+      double search_radius_{0.0};
 
       /** \brief The number of K nearest neighbors to use for each point. */
-      int k_;
+      int k_{0};
 
       /** \brief Indices of the keypoints in the input cloud. */
       pcl::PointIndicesPtr keypoints_indices_;
