@@ -46,12 +46,7 @@ namespace octree {
 //////////////////////////////////////////////////////////////////////////////////////////////
 template <typename LeafContainerT, typename BranchContainerT>
 OctreeBase<LeafContainerT, BranchContainerT>::OctreeBase()
-: leaf_count_(0)
-, branch_count_(1)
-, root_node_(new BranchNode())
-, depth_mask_(0)
-, octree_depth_(0)
-, dynamic_depth_enabled_(false)
+: root_node_(new BranchNode())
 {}
 
 //////////////////////////////////////////////////////////////////////////////////////////////
@@ -71,7 +66,12 @@ OctreeBase<LeafContainerT, BranchContainerT>::setMaxVoxelIndex(
 {
   uindex_t tree_depth;
 
-  assert(max_voxel_index_arg > 0);
+  if (max_voxel_index_arg <= 0) {
+    PCL_ERROR("[pcl::octree::OctreeBase::setMaxVoxelIndex] Max voxel index (%lu) must "
+              "be > 0!\n",
+              max_voxel_index_arg);
+    return;
+  }
 
   // tree depth == bitlength of maxVoxels
   tree_depth =
@@ -86,8 +86,18 @@ template <typename LeafContainerT, typename BranchContainerT>
 void
 OctreeBase<LeafContainerT, BranchContainerT>::setTreeDepth(uindex_t depth_arg)
 {
-  assert(depth_arg > 0);
-  assert(depth_arg <= OctreeKey::maxDepth);
+  if (depth_arg <= 0) {
+    PCL_ERROR("[pcl::octree::OctreeBase::setTreeDepth] Tree depth (%lu) must be > 0!\n",
+              depth_arg);
+    return;
+  }
+  if (depth_arg > OctreeKey::maxDepth) {
+    PCL_ERROR("[pcl::octree::OctreeBase::setTreeDepth] Tree depth (%lu) must be <= max "
+              "depth(%lu)!\n",
+              depth_arg,
+              OctreeKey::maxDepth);
+    return;
+  }
 
   // set octree depth
   octree_depth_ = depth_arg;
