@@ -72,9 +72,11 @@ public:
 
   using KdTree = pcl::search::KdTree<PointTarget>;
   using KdTreePtr = typename KdTree::Ptr;
+  using KdTreeConstPtr = typename KdTree::ConstPtr;
 
   using KdTreeReciprocal = pcl::search::KdTree<PointSource>;
-  using KdTreeReciprocalPtr = typename KdTree::Ptr;
+  using KdTreeReciprocalPtr = typename KdTreeReciprocal::Ptr;
+  using KdTreeReciprocalConstPtr = typename KdTreeReciprocal::ConstPtr;
 
   using PointCloudSource = pcl::PointCloud<PointSource>;
   using PointCloudSourcePtr = typename PointCloudSource::Ptr;
@@ -85,6 +87,8 @@ public:
   using PointCloudTargetConstPtr = typename PointCloudTarget::ConstPtr;
 
   using PointRepresentationConstPtr = typename KdTree::PointRepresentationConstPtr;
+  using PointRepresentationReciprocalConstPtr =
+      typename KdTreeReciprocal::PointRepresentationConstPtr;
 
   /** \brief Empty constructor. */
   CorrespondenceEstimationBase()
@@ -94,10 +98,6 @@ public:
   , target_()
   , point_representation_()
   , input_transformed_()
-  , target_cloud_updated_(true)
-  , source_cloud_updated_(true)
-  , force_no_recompute_(false)
-  , force_no_recompute_reciprocal_(false)
   {}
 
   /** \brief Empty destructor */
@@ -275,8 +275,8 @@ public:
       pcl::Correspondences& correspondences,
       double max_distance = std::numeric_limits<double>::max()) = 0;
 
-  /** \brief Provide a boost shared pointer to the PointRepresentation to be used
-   * when searching for nearest neighbors.
+  /** \brief Provide a boost shared pointer to the PointRepresentation for target cloud
+   * to be used when searching for nearest neighbors.
    *
    * \param[in] point_representation the PointRepresentation to be used by the
    * k-D tree for nearest neighbor search
@@ -287,6 +287,19 @@ public:
     point_representation_ = point_representation;
   }
 
+  /** \brief Provide a boost shared pointer to the PointRepresentation for source cloud
+   * to be used when searching for nearest neighbors.
+   *
+   * \param[in] point_representation the PointRepresentation to be used by the
+   * k-D tree for nearest neighbor search
+   */
+  inline void
+  setPointRepresentationReciprocal(
+      const PointRepresentationReciprocalConstPtr& point_representation_reciprocal)
+  {
+    point_representation_reciprocal_ = point_representation_reciprocal;
+  }
+
   /** \brief Clone and cast to CorrespondenceEstimationBase */
   virtual typename CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::Ptr
   clone() const = 0;
@@ -307,9 +320,12 @@ protected:
   /** \brief The target point cloud dataset indices. */
   IndicesPtr target_indices_;
 
-  /** \brief The point representation used (internal). */
+  /** \brief The target point representation used (internal). */
   PointRepresentationConstPtr point_representation_;
 
+  /** \brief The source point representation used (internal). */
+  PointRepresentationReciprocalConstPtr point_representation_reciprocal_;
+
   /** \brief The transformed input source point cloud dataset. */
   PointCloudTargetPtr input_transformed_;
 
@@ -334,18 +350,18 @@ protected:
   /** \brief Variable that stores whether we have a new target cloud, meaning we need to
    * pre-process it again. This way, we avoid rebuilding the kd-tree for the target
    * cloud every time the determineCorrespondences () method is called. */
-  bool target_cloud_updated_;
+  bool target_cloud_updated_{true};
   /** \brief Variable that stores whether we have a new source cloud, meaning we need to
    * pre-process it again. This way, we avoid rebuilding the reciprocal kd-tree for the
    * source cloud every time the determineCorrespondences () method is called. */
-  bool source_cloud_updated_;
+  bool source_cloud_updated_{true};
   /** \brief A flag which, if set, means the tree operating on the target cloud
    * will never be recomputed*/
-  bool force_no_recompute_;
+  bool force_no_recompute_{false};
 
   /** \brief A flag which, if set, means the tree operating on the source cloud
    * will never be recomputed*/
-  bool force_no_recompute_reciprocal_;
+  bool force_no_recompute_reciprocal_{false};
 };
 
 /** \brief @b CorrespondenceEstimation represents the base class for
@@ -396,8 +412,24 @@ public:
   using CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::input_fields_;
   using PCLBase<PointSource>::deinitCompute;
 
-  using KdTree = pcl::search::KdTree<PointTarget>;
-  using KdTreePtr = typename KdTree::Ptr;
+  using KdTree =
+      typename CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::KdTree;
+  using KdTreePtr = typename CorrespondenceEstimationBase<PointSource,
+                                                          PointTarget,
+                                                          Scalar>::KdTreePtr;
+  using KdTreeConstPtr = typename CorrespondenceEstimationBase<PointSource,
+                                                               PointTarget,
+                                                               Scalar>::KdTreeConstPtr;
+  using KdTreeReciprocal =
+      typename CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::
+          KdTreeReciprocal;
+  using KdTreeReciprocalPtr =
+      typename CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::
+          KdTreeReciprocalPtr;
+
+  using KdTreeReciprocalConstPtr =
+      typename CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::
+          KdTreeReciprocalConstPtr;
 
   using PointCloudSource = pcl::PointCloud<PointSource>;
   using PointCloudSourcePtr = typename PointCloudSource::Ptr;
@@ -408,6 +440,8 @@ public:
   using PointCloudTargetConstPtr = typename PointCloudTarget::ConstPtr;
 
   using PointRepresentationConstPtr = typename KdTree::PointRepresentationConstPtr;
+  using PointRepresentationReciprocalConstPtr =
+      typename KdTreeReciprocal::PointRepresentationConstPtr;
 
   /** \brief Empty constructor. */
   CorrespondenceEstimation() { corr_name_ = "CorrespondenceEstimation"; }
