@@ -99,7 +99,7 @@ public:
    * Sets the number of neighbors to be considered in the target point cloud (k_) to 10.
    */
   CorrespondenceEstimationBackProjection()
-  : source_normals_(), source_normals_transformed_(), target_normals_(), k_(10)
+  : source_normals_(), source_normals_transformed_(), target_normals_()
   {
     corr_name_ = "CorrespondenceEstimationBackProjection";
   }
@@ -250,7 +250,7 @@ private:
   NormalsConstPtr target_normals_;
 
   /** \brief The number of neighbours to be considered in the target point cloud */
-  unsigned int k_;
+  unsigned int k_{10};
 };
 } // namespace registration
 } // namespace pcl
