@@ -67,14 +67,7 @@ public:
   /** \brief Empty constructor. Sets the inlier threshold to 5cm (0.05m),
    * and the maximum number of iterations to 1000.
    */
-  CorrespondenceRejectorSampleConsensus()
-  : inlier_threshold_(0.05)
-  , max_iterations_(1000) // std::numeric_limits<int>::max ()
-  , input_()
-  , input_transformed_()
-  , target_()
-  , refine_(false)
-  , save_inliers_(false)
+  CorrespondenceRejectorSampleConsensus() : input_(), input_transformed_(), target_()
   {
     rejection_name_ = "CorrespondenceRejectorSampleConsensus";
   }
@@ -256,9 +249,9 @@ protected:
     getRemainingCorrespondences(*input_correspondences_, correspondences);
   }
 
-  double inlier_threshold_;
+  double inlier_threshold_{0.05};
 
-  int max_iterations_;
+  int max_iterations_{1000};
 
   PointCloudConstPtr input_;
   PointCloudPtr input_transformed_;
@@ -266,9 +259,9 @@ protected:
 
   Eigen::Matrix4f best_transformation_;
 
-  bool refine_;
+  bool refine_{false};
   pcl::Indices inlier_indices_;
-  bool save_inliers_;
+  bool save_inliers_{false};
 
 public:
   PCL_MAKE_ALIGNED_OPERATOR_NEW
