@@ -47,7 +47,8 @@
 #include <pcl/registration/transformation_estimation_point_to_plane_lls.h>
 #include <pcl/registration/transformation_estimation_svd.h>
 #include <pcl/registration/transformation_estimation_symmetric_point_to_plane_lls.h>
-#include <pcl/memory.h> // for dynamic_pointer_cast, pcl::make_shared, shared_ptr
+#include <pcl/memory.h>     // for dynamic_pointer_cast, pcl::make_shared, shared_ptr
+#include <pcl/pcl_config.h> // for PCL_NO_PRECOMPILE
 
 namespace pcl {
 /** \brief @b IterativeClosestPoint provides a base implementation of the Iterative
@@ -143,15 +144,6 @@ public:
 
   /** \brief Empty constructor. */
   IterativeClosestPoint()
-  : x_idx_offset_(0)
-  , y_idx_offset_(0)
-  , z_idx_offset_(0)
-  , nx_idx_offset_(0)
-  , ny_idx_offset_(0)
-  , nz_idx_offset_(0)
-  , use_reciprocal_correspondence_(false)
-  , source_has_normals_(false)
-  , target_has_normals_(false)
   {
     reg_name_ = "IterativeClosestPoint";
     transformation_estimation_.reset(
@@ -296,18 +288,18 @@ protected:
   determineRequiredBlobData();
 
   /** \brief XYZ fields offset. */
-  std::size_t x_idx_offset_, y_idx_offset_, z_idx_offset_;
+  std::size_t x_idx_offset_{0}, y_idx_offset_{0}, z_idx_offset_{0};
 
   /** \brief Normal fields offset. */
-  std::size_t nx_idx_offset_, ny_idx_offset_, nz_idx_offset_;
+  std::size_t nx_idx_offset_{0}, ny_idx_offset_{0}, nz_idx_offset_{0};
 
   /** \brief The correspondence type used for correspondence estimation. */
-  bool use_reciprocal_correspondence_;
+  bool use_reciprocal_correspondence_{false};
 
   /** \brief Internal check whether source dataset has normals or not. */
-  bool source_has_normals_;
+  bool source_has_normals_{false};
   /** \brief Internal check whether target dataset has normals or not. */
-  bool target_has_normals_;
+  bool target_has_normals_{false};
 
   /** \brief Checks for whether estimators and rejectors need various data */
   bool need_source_blob_, need_target_blob_;
@@ -456,3 +448,9 @@ protected:
 } // namespace pcl
 
 #include <pcl/registration/impl/icp.hpp>
+
+#if !defined(PCL_NO_PRECOMPILE) && !defined(PCL_REGISTRATION_ICP_CPP_)
+extern template class pcl::IterativeClosestPoint<pcl::PointXYZ, pcl::PointXYZ>;
+extern template class pcl::IterativeClosestPoint<pcl::PointXYZI, pcl::PointXYZI>;
+extern template class pcl::IterativeClosestPoint<pcl::PointXYZRGB, pcl::PointXYZRGB>;
+#endif // PCL_NO_PRECOMPILE
