@@ -60,6 +60,7 @@ namespace pcl {
  * Optimization Theory and Methods: Nonlinear Programming. 89-100
  * \note Math refactored by Todor Stoyanov.
  * \author Brian Okorn (Space and Naval Warfare Systems Center Pacific)
+ * \ingroup registration
  */
 template <typename PointSource, typename PointTarget, typename Scalar = float>
 class NormalDistributionsTransform
@@ -228,9 +229,9 @@ public:
   convertTransform(const Eigen::Matrix<double, 6, 1>& x, Affine3& trans)
   {
     trans = Eigen::Translation<Scalar, 3>(x.head<3>().cast<Scalar>()) *
-            Eigen::AngleAxis<Scalar>(Scalar(x(3)), Vector3::UnitX()) *
-            Eigen::AngleAxis<Scalar>(Scalar(x(4)), Vector3::UnitY()) *
-            Eigen::AngleAxis<Scalar>(Scalar(x(5)), Vector3::UnitZ());
+            Eigen::AngleAxis<Scalar>(static_cast<Scalar>(x(3)), Vector3::UnitX()) *
+            Eigen::AngleAxis<Scalar>(static_cast<Scalar>(x(4)), Vector3::UnitY()) *
+            Eigen::AngleAxis<Scalar>(static_cast<Scalar>(x(5)), Vector3::UnitZ());
   }
 
   /** \brief Convert 6 element transformation vector to transformation matrix.
@@ -404,7 +405,7 @@ protected:
    * Thuente 1994) and \f$ \delta \vec{p} \f$ normalized in Algorithm 2
    * [Magnusson 2009]
    * \param[in] step_init initial step length estimate, \f$ \alpha_0 \f$ in
-   * Moore-Thuente (1994) and the noramal of \f$ \delta \vec{p} \f$ in Algorithm
+   * Moore-Thuente (1994) and the normal of \f$ \delta \vec{p} \f$ in Algorithm
    * 2 [Magnusson 2009]
    * \param[in] step_max maximum step length, \f$ \alpha_max \f$ in
    * Moore-Thuente (1994)
@@ -556,18 +557,18 @@ protected:
   TargetGrid target_cells_;
 
   /** \brief The side length of voxels. */
-  float resolution_;
+  float resolution_{1.0f};
 
   /** \brief The maximum step length. */
-  double step_size_;
+  double step_size_{0.1};
 
   /** \brief The ratio of outliers of points w.r.t. a normal distribution,
    * Equation 6.7 [Magnusson 2009]. */
-  double outlier_ratio_;
+  double outlier_ratio_{0.55};
 
   /** \brief The normalization constants used fit the point distribution to a
    * normal distribution, Equation 6.8 [Magnusson 2009]. */
-  double gauss_d1_, gauss_d2_;
+  double gauss_d1_{0.0}, gauss_d2_{0.0};
 
   /** \brief The likelihood score of the transform applied to the input cloud,
    * Equation 6.9 and 6.10 [Magnusson 2009]. */
@@ -576,7 +577,7 @@ protected:
                    16,
                    "`trans_probability_` has been renamed to `trans_likelihood_`.")
     double trans_probability_;
-    double trans_likelihood_;
+    double trans_likelihood_{0.0};
   };
 
   /** \brief Precomputed Angular Gradient
