@@ -108,8 +108,11 @@ pcl::RandomizedMEstimatorSampleConsensus<PointT>::computeModel (int debug_verbos
     // Iterate through the 3d points and calculate the distances from them to the model
     sac_model_->getDistancesToModel (model_coefficients, distances);
 
-    if (distances.empty () && k > 1.0)
+    if (distances.empty ())
+    {
+      ++ skipped_count;
       continue;
+    }
 
     for (const double &distance : distances)
       d_cur_penalty += std::min (distance, threshold_);
