@@ -7,11 +7,12 @@
 
 #pragma once
 
+#include <pcl/memory.h>
 #include <pcl/pcl_exports.h>
 
 #include <Eigen/Core>
+
 #include <GL/glew.h>
-#include <pcl/make_shared.h>
 
 namespace pcl {
 namespace simulation {
@@ -39,7 +40,7 @@ public:
 
   /** Add a new shader object to the program.  */
   bool
-  addShaderText(const std::string& text, ShaderType shader_type);
+  addShaderText(const std::string& text, ShaderType shader_type) const;
 
   /** Add a new shader object to the program.  */
   bool
@@ -47,7 +48,7 @@ public:
 
   /** Link the program.  */
   bool
-  link();
+  link() const;
 
   /** Return true if the program is linked.  */
   bool
@@ -55,7 +56,7 @@ public:
 
   /** Use the program.  */
   void
-  use();
+  use() const;
 
   // Set uniforms
   void
@@ -86,7 +87,7 @@ public:
   setUniform(const std::string& name, bool v);
 
   int
-  getUniformLocation(const std::string& name);
+  getUniformLocation(const std::string& name) const;
 
   void
   printActiveUniforms();
@@ -94,7 +95,7 @@ public:
   printActiveAttribs();
 
   GLuint
-  programId()
+  programId() const
   {
     return program_id_;
   }
