@@ -123,6 +123,7 @@ namespace pcl
   /** \brief GreedyProjectionTriangulation is an implementation of a greedy triangulation algorithm for 3D points
     * based on local 2D projections. It assumes locally smooth surfaces and relatively smooth transitions between
     * areas with different point densities.
+    * \tparam PointInT Point type must have XYZ and normal information, for example `pcl::PointNormal` or `pcl::PointXYZRGBNormal` or `pcl::PointXYZINormal`
     * \author Zoltan Csaba Marton
     * \ingroup surface
     */
@@ -154,28 +155,7 @@ namespace pcl
       };
     
       /** \brief Empty constructor. */
-      GreedyProjectionTriangulation () : 
-        mu_ (0), 
-        search_radius_ (0), // must be set by user
-        nnn_ (100),
-        minimum_angle_ (M_PI/18), // 10 degrees
-        maximum_angle_ (2*M_PI/3), // 120 degrees
-        eps_angle_(M_PI/4), //45 degrees,
-        consistent_(false), 
-        consistent_ordering_ (false),
-        angles_ (),
-        R_ (),
-        is_current_free_ (false),
-        current_index_ (),
-        prev_is_ffn_ (false),
-        prev_is_sfn_ (false),
-        next_is_ffn_ (false),
-        next_is_sfn_ (false),
-        changed_1st_fn_ (false),
-        changed_2nd_fn_ (false),
-        new2boundary_ (),
-        already_connected_ (false)
-      {};
+      GreedyProjectionTriangulation () = default;
 
       /** \brief Set the multiplier of the nearest neighbor distance to obtain the final search radius for each point
        *  (this will make the algorithm adapt to different point densities in the cloud).
@@ -287,28 +267,28 @@ namespace pcl
 
     protected:
       /** \brief The nearest neighbor distance multiplier to obtain the final search radius. */
-      double mu_;
+      double mu_{0.0};
 
       /** \brief The nearest neighbors search radius for each point and the maximum edge length. */
-      double search_radius_;
+      double search_radius_{0.0};
 
       /** \brief The maximum number of nearest neighbors accepted by searching. */
-      int nnn_;
+      int nnn_{100};
 
       /** \brief The preferred minimum angle for the triangles. */
-      double minimum_angle_;
+      double minimum_angle_{M_PI/18};
 
       /** \brief The maximum angle for the triangles. */
-      double maximum_angle_;
+      double maximum_angle_{2*M_PI/3};
 
       /** \brief Maximum surface angle. */
-      double eps_angle_;
+      double eps_angle_{M_PI/4};
 
       /** \brief Set this to true if the normals of the input are consistently oriented. */
-      bool consistent_;
+      bool consistent_{false};
       
       /** \brief Set this to true if the output triangle vertices should be consistently oriented. */
-      bool consistent_ordering_;
+      bool consistent_ordering_{false};
 
      private:
       /** \brief Struct for storing the angles to nearest neighbors **/
@@ -323,8 +303,8 @@ namespace pcl
       /** \brief Struct for storing the edges starting from a fringe point **/
       struct doubleEdge
       {
-        doubleEdge () : index (0) {}
-        int index;
+        doubleEdge () = default;
+        int index{0};
         Eigen::Vector2f first;
         Eigen::Vector2f second;
       };
@@ -332,50 +312,50 @@ namespace pcl
       // Variables made global to decrease the number of parameters to helper functions
 
       /** \brief Temporary variable to store a triangle (as a set of point indices) **/
-      pcl::Vertices triangle_;
+      pcl::Vertices triangle_{};
       /** \brief Temporary variable to store point coordinates **/
-      std::vector<Eigen::Vector3f, Eigen::aligned_allocator<Eigen::Vector3f> > coords_;
+      std::vector<Eigen::Vector3f, Eigen::aligned_allocator<Eigen::Vector3f> > coords_{};
 
       /** \brief A list of angles to neighbors **/
-      std::vector<nnAngle> angles_;
+      std::vector<nnAngle> angles_{};
       /** \brief Index of the current query point **/
-      pcl::index_t R_;
+      pcl::index_t R_{};
       /** \brief List of point states **/
-      std::vector<int> state_;
+      std::vector<int> state_{};
       /** \brief List of sources **/
-      pcl::Indices source_;
+      pcl::Indices source_{};
       /** \brief List of fringe neighbors in one direction **/
-      pcl::Indices ffn_;
+      pcl::Indices ffn_{};
       /** \brief List of fringe neighbors in other direction **/
-      pcl::Indices sfn_;
+      pcl::Indices sfn_{};
       /** \brief Connected component labels for each point **/
-      std::vector<int> part_;
+      std::vector<int> part_{};
       /** \brief Points on the outer edge from which the mesh has to be grown **/
-      std::vector<int> fringe_queue_;
+      std::vector<int> fringe_queue_{};
 
       /** \brief Flag to set if the current point is free **/
-      bool is_current_free_;
+      bool is_current_free_{false};
       /** \brief Current point's index **/
-      pcl::index_t current_index_;
+      pcl::index_t current_index_{};
       /** \brief Flag to set if the previous point is the first fringe neighbor **/
-      bool prev_is_ffn_;
+      bool prev_is_ffn_{false};
       /** \brief Flag to set if the next point is the second fringe neighbor **/
-      bool prev_is_sfn_;
+      bool prev_is_sfn_{false};
       /** \brief Flag to set if the next point is the first fringe neighbor **/
-      bool next_is_ffn_;
+      bool next_is_ffn_{false};
       /** \brief Flag to set if the next point is the second fringe neighbor **/
-      bool next_is_sfn_;
+      bool next_is_sfn_{false};
       /** \brief Flag to set if the first fringe neighbor was changed **/
-      bool changed_1st_fn_;
+      bool changed_1st_fn_{false};
       /** \brief Flag to set if the second fringe neighbor was changed **/
-      bool changed_2nd_fn_;
+      bool changed_2nd_fn_{false};
       /** \brief New boundary point **/
-      pcl::index_t new2boundary_;
+      pcl::index_t new2boundary_{};
       
       /** \brief Flag to set if the next neighbor was already connected in the previous step.
         * To avoid inconsistency it should not be connected again.
         */
-      bool already_connected_; 
+      bool already_connected_{false}; 
 
       /** \brief Point coordinates projected onto the plane defined by the point normal **/
       Eigen::Vector3f proj_qp_;
