@@ -177,7 +177,7 @@ SequentialFitter::project (const Eigen::Vector3d &pt)
     pr (0) = -pr (0);
     pr (1) = -pr (1);
   }
-  return Eigen::Vector2d (pr (0), pr (1));
+  return {pr(0), pr(1)};
 }
 
 bool
@@ -482,18 +482,17 @@ SequentialFitter::grow (float max_dist, float max_angle, unsigned min_length, un
 
   if (unsigned (this->m_data.boundary.size ()) != num_bnd)
   {
-    printf ("[SequentialFitter::grow] %lu %u\n", this->m_data.boundary.size (), num_bnd);
+    printf ("[SequentialFitter::grow] %zu %u\n", this->m_data.boundary.size (), num_bnd);
     throw std::runtime_error ("[SequentialFitter::grow] size of boundary and boundary parameters do not match.");
   }
 
   if (this->m_boundary_indices->indices.size () != num_bnd)
   {
-    printf ("[SequentialFitter::grow] %lu %u\n", this->m_boundary_indices->indices.size (), num_bnd);
+    printf ("[SequentialFitter::grow] %zu %u\n", this->m_boundary_indices->indices.size (), num_bnd);
     throw std::runtime_error ("[SequentialFitter::grow] size of boundary indices and boundary parameters do not match.");
   }
 
   float angle = std::cos (max_angle);
-  unsigned bnd_moved (0);
 
   for (unsigned i = 0; i < num_bnd; i++)
   {
@@ -584,7 +583,6 @@ SequentialFitter::grow (float max_dist, float max_angle, unsigned min_length, un
       this->m_data.boundary[i] (0) = point.x;
       this->m_data.boundary[i] (1) = point.y;
       this->m_data.boundary[i] (2) = point.z;
-      bnd_moved++;
     }
 
   } // i
