@@ -42,10 +42,7 @@
 #include <vtkQuadricDecimation.h>
 
 //////////////////////////////////////////////////////////////////////////////////////////////
-pcl::MeshQuadricDecimationVTK::MeshQuadricDecimationVTK ()
-  : target_reduction_factor_ (0.5f)
-{
-}
+pcl::MeshQuadricDecimationVTK::MeshQuadricDecimationVTK () = default;
 
 
 //////////////////////////////////////////////////////////////////////////////////////////////
