@@ -212,7 +212,7 @@ pcl::VTKUtils::mesh2vtk (const pcl::PolygonMesh& mesh, vtkSmartPointer<vtkPolyDa
     Eigen::Array4i xyz_offset (mesh.cloud.fields[idx_x].offset, mesh.cloud.fields[idx_y].offset, mesh.cloud.fields[idx_z].offset, 0);
     for (vtkIdType cp = 0; cp < nr_points; ++cp, xyz_offset += mesh.cloud.point_step)
     {
-      memcpy(&pt[0], &mesh.cloud.data[xyz_offset[0]], sizeof(float));
+      memcpy(&pt[0], &mesh.cloud.data[xyz_offset[0]], sizeof(float)); // NOLINT(readability-container-data-pointer)
       memcpy(&pt[1], &mesh.cloud.data[xyz_offset[1]], sizeof(float));
       memcpy(&pt[2], &mesh.cloud.data[xyz_offset[2]], sizeof(float));
       vtk_mesh_points->InsertPoint(cp, pt[0], pt[1], pt[2]);
