@@ -67,7 +67,7 @@ using namespace pcl::outofcore;
 
 // For doing exhaustive checks this is set low remove those, and this can be
 // set much higher
-const static std::uint64_t numPts (10000);
+constexpr std::uint64_t numPts (10000);
 
 constexpr std::uint32_t rngseed = 0xAAFF33DD;
 
@@ -394,7 +394,7 @@ class OutofcoreTest : public testing::Test
 {
   protected:
 
-    OutofcoreTest () : smallest_voxel_dim () {}
+    OutofcoreTest () = default;
 
     void SetUp () override
     {
@@ -420,7 +420,7 @@ class OutofcoreTest : public testing::Test
 
     }
 
-    double smallest_voxel_dim;
+    double smallest_voxel_dim{3.0f};
 
 };
 
@@ -702,7 +702,7 @@ TEST_F (OutofcoreTest, PointCloud2_Constructors)
   const Eigen::Vector3d min (-100.1, -100.1, -100.1);
   const Eigen::Vector3d max (100.1, 100.1, 100.1);
   
-  const std::uint64_t depth = 2;
+  constexpr std::uint64_t depth = 2;
   
   //create a point cloud
   pcl::PointCloud<PointT>::Ptr test_cloud (new pcl::PointCloud<PointT> ());
@@ -833,7 +833,7 @@ TEST_F (OutofcoreTest, PointCloud2_QueryBoundingBox)
   const Eigen::Vector3d min (-100.1, -100.1, -100.1);
   const Eigen::Vector3d max (100.1, 100.1, 100.1);
   
-  const std::uint64_t depth = 2;
+  constexpr std::uint64_t depth = 2;
 
   //create a point cloud
   pcl::PointCloud<PointT>::Ptr test_cloud (new pcl::PointCloud<PointT> ());
@@ -885,7 +885,7 @@ TEST_F (OutofcoreTest, PointCloud2_Query)
   const Eigen::Vector3d min (-100.1, -100.1, -100.1);
   const Eigen::Vector3d max (100.1, 100.1, 100.1);
   
-  const std::uint64_t depth = 2;
+  constexpr std::uint64_t depth = 2;
   
   //create a point cloud
   pcl::PointCloud<PointT>::Ptr test_cloud (new pcl::PointCloud<PointT> ());
@@ -920,7 +920,7 @@ TEST_F (OutofcoreTest, PointCloud2_Query)
   pcl::PCLPointCloud2::Ptr query_result_a (new pcl::PCLPointCloud2 ());
   pcl::PCLPointCloud2::Ptr query_result_b (new pcl::PCLPointCloud2 ());
 
-  octreeA.queryBBIncludes (min, max, int (octreeA.getDepth ()), query_result_a);
+  octreeA.queryBBIncludes (min, max, static_cast<int>(octreeA.getDepth ()), query_result_a);
   
   EXPECT_EQ (test_cloud->width*test_cloud->height, query_result_a->width*query_result_a->height) << "PCLPointCloud2 Query number of points returned failed\n";
 
