@@ -55,7 +55,7 @@ TEST (PCL, FPCSInitialAlignment)
   // transform the source cloud by a large amount
   Eigen::Vector3f initial_offset (1.f, 0.f, 0.f);
   float angle = static_cast<float> (M_PI) / 2.f;
-  Eigen::Quaternionf initial_rotation (std::cos (angle / 2.f), 0, 0, sin (angle / 2.f));
+  Eigen::Quaternionf initial_rotation (std::cos (angle / 2.f), 0, 0, std::sin (angle / 2.f));
   PointCloud<PointXYZ> cloud_source_transformed;
   transformPointCloud (cloud_source, cloud_source_transformed, initial_offset, initial_rotation);
 
