@@ -88,7 +88,7 @@ TEST (PCL, CorrespondenceEstimation)
 
   // check for correct order and number of matches
   EXPECT_EQ (int (correspondences->size ()), nr_original_correspondences);
-  if (int (correspondences->size ()) == nr_original_correspondences)
+  if (static_cast<int>(correspondences->size ()) == nr_original_correspondences)
   {
     for (int i = 0; i < nr_original_correspondences; ++i)
     {
@@ -112,7 +112,7 @@ TEST (PCL, CorrespondenceEstimationReciprocal)
 
   // check for correct matches and number of matches
   EXPECT_EQ (int (correspondences->size ()), nr_reciprocal_correspondences);
-  if (int (correspondences->size ()) == nr_reciprocal_correspondences)
+  if (static_cast<int>(correspondences->size ()) == nr_reciprocal_correspondences)
   {
     for (int i = 0; i < nr_reciprocal_correspondences; ++i)
     {
@@ -143,7 +143,7 @@ TEST (PCL, CorrespondenceRejectorDistance)
 
   // check for correct matches and number of matches
   EXPECT_EQ (int (correspondences_result_rej_dist->size ()), nr_correspondences_result_rej_dist);
-  if (int (correspondences_result_rej_dist->size ()) == nr_correspondences_result_rej_dist)
+  if (static_cast<int>(correspondences_result_rej_dist->size ()) == nr_correspondences_result_rej_dist)
   {
     for (int i = 0; i < nr_correspondences_result_rej_dist; ++i)
     {
@@ -176,7 +176,7 @@ TEST (PCL, CorrespondenceRejectorMedianDistance)
   // check for correct matches
   EXPECT_NEAR (corr_rej_median_dist.getMedianDistance (), rej_median_distance, 1e-4);
   EXPECT_EQ (int (correspondences_result_rej_median_dist->size ()), nr_correspondences_result_rej_median_dist);
-  if (int (correspondences_result_rej_median_dist->size ()) == nr_correspondences_result_rej_median_dist)
+  if (static_cast<int>(correspondences_result_rej_median_dist->size ()) == nr_correspondences_result_rej_median_dist)
   {
     for (int i = 0; i < nr_correspondences_result_rej_median_dist; ++i)
     {
@@ -206,7 +206,7 @@ TEST (PCL, CorrespondenceRejectorOneToOne)
 
   // check for correct matches and number of matches
   EXPECT_EQ (int (correspondences_result_rej_one_to_one->size ()), nr_correspondences_result_rej_one_to_one);
-  if (int (correspondences_result_rej_one_to_one->size ()) == nr_correspondences_result_rej_one_to_one)
+  if (static_cast<int>(correspondences_result_rej_one_to_one->size ()) == nr_correspondences_result_rej_one_to_one)
   {
     for (int i = 0; i < nr_correspondences_result_rej_one_to_one; ++i)
     {
@@ -242,7 +242,7 @@ TEST (PCL, CorrespondenceRejectorSampleConsensus)
 
   // check for correct matches and number of matches
   EXPECT_EQ (int (correspondences_result_rej_sac->size ()), nr_correspondences_result_rej_sac);
-  if (int (correspondences_result_rej_sac->size ()) == nr_correspondences_result_rej_sac)
+  if (static_cast<int>(correspondences_result_rej_sac->size ()) == nr_correspondences_result_rej_sac)
   {
     for (int i = 0; i < nr_correspondences_result_rej_sac; ++i)
     {
@@ -302,7 +302,7 @@ TEST (PCL, CorrespondenceRejectorSurfaceNormal)
   corr_rej_surf_norm.getCorrespondences (*correspondences_result_rej_surf_norm);
 
   // check for correct matches
-  if (int (correspondences_result_rej_surf_norm->size ()) == nr_correspondences_result_rej_dist)
+  if (static_cast<int>(correspondences_result_rej_surf_norm->size ()) == nr_correspondences_result_rej_dist)
   {
     for (int i = 0; i < nr_correspondences_result_rej_dist; ++i)
     {
@@ -332,7 +332,7 @@ TEST (PCL, CorrespondenceRejectorTrimmed)
 
   // check for correct matches, number of matches, and for sorting (correspondences should be sorted w.r.t. distance)
   EXPECT_EQ (int (correspondences_result_rej_trimmed->size ()), nr_correspondences_result_rej_trimmed);
-  if (int (correspondences_result_rej_trimmed->size ()) == nr_correspondences_result_rej_trimmed)
+  if (static_cast<int>(correspondences_result_rej_trimmed->size ()) == nr_correspondences_result_rej_trimmed)
   {
     for (int i = 0; i < nr_correspondences_result_rej_trimmed; ++i)
     {
@@ -364,7 +364,7 @@ TEST (PCL, CorrespondenceRejectorVarTrimmed)
   corr_rej_var_trimmed_dist.getCorrespondences(*correspondences_result_rej_var_trimmed_dist);
 
   // check for correct matches
-  if (int (correspondences_result_rej_var_trimmed_dist->size ()) == nr_correspondences_result_rej_dist)
+  if (static_cast<int>(correspondences_result_rej_var_trimmed_dist->size ()) == nr_correspondences_result_rej_dist)
   {
     for (int i = 0; i < nr_correspondences_result_rej_dist; ++i)
     {
