@@ -43,30 +43,22 @@
 #include <pcl/point_types.h>
 #include <pcl/io/pcd_io.h>
 #include <pcl/search/organized.h> // for OrganizedNeighbor
+#include "precise_distances.h" // for point_distance
+
+#define TOLERANCE 0.000001
 
 using namespace pcl;
 
 std::string pcd_filename;
 
-// Here we want a very precise distance function, speed is less important. So we use
-// double precision, unlike euclideanDistance() in pcl/common/distances and distance()
-// in pcl/common/geometry which use float (single precision) and possibly vectorization
-template <typename PointT> inline double
-point_distance(const PointT& p1, const PointT& p2)
-{
-  const double x_diff = p1.x - p2.x, y_diff = p1.y - p2.y, z_diff = p1.z - p2.z;
-  return std::sqrt(x_diff * x_diff + y_diff * y_diff + z_diff * z_diff);
-}
-
 // helper class for priority queue
 class prioPointQueueEntry
 {
   public:
-    prioPointQueueEntry ()
-    = default;
+    prioPointQueueEntry () = default;
     prioPointQueueEntry (PointXYZ& point_arg, double pointDistance_arg, int pointIdx_arg)
+      : point_ (point_arg)
     {
-      point_ = point_arg;
       pointDistance_ = pointDistance_arg;
       pointIdx_ = pointIdx_arg;
     }
@@ -122,9 +114,9 @@ TEST (PCL, Organized_Neighbor_Search_Pointcloud_Nearest_K_Neighbour_Search)
     for (int ypos = -centerY; ypos < centerY; ypos++)
       for (int xpos = -centerX; xpos < centerX; xpos++)
       {
-        double z = 15.0 * ((double)rand () / (double)(RAND_MAX+1.0))+20;
-        double y = (double)ypos*oneOverFocalLength*(double)z;
-        double x = (double)xpos*oneOverFocalLength*(double)z;
+        double z = 15.0 * (static_cast<double>(rand ()) / (RAND_MAX+1.0))+20;
+        double y = static_cast<double>(ypos)*oneOverFocalLength*z;
+        double x = static_cast<double>(xpos)*oneOverFocalLength*z;
 
         cloudIn->points.emplace_back(x, y, z);
       }
@@ -146,7 +138,7 @@ TEST (PCL, Organized_Neighbor_Search_Pointcloud_Nearest_K_Neighbour_Search)
 
     for (auto it = cloudIn->begin(); it != cloudIn->end(); ++it)
     {
-      const auto pointDist = point_distance(*it, searchPoint);
+      const auto pointDist = pcl_tests::point_distance(*it, searchPoint);
       prioPointQueueEntry pointEntry (*it, pointDist, std::distance(cloudIn->begin(), it));
       pointCandidates.push (pointEntry);
     }
@@ -228,7 +220,7 @@ TEST (PCL, Organized_Neighbor_Search_Pointcloud_Nearest_K_Neighbour_Search_Kinec
 
     // organized nearest neighbor search
     organizedNeighborSearch.setInputCloud (cloudIn);
-    organizedNeighborSearch.nearestKSearch (searchPoint, (int)K, k_indices, k_sqr_distances);
+    organizedNeighborSearch.nearestKSearch (searchPoint, static_cast<int>(K), k_indices, k_sqr_distances);
 
     k_indices_bruteforce.clear();
     k_sqr_distances_bruteforce.clear();
@@ -239,7 +231,7 @@ TEST (PCL, Organized_Neighbor_Search_Pointcloud_Nearest_K_Neighbour_Search_Kinec
     // push all points and their distance to the search point into a priority queue - bruteforce approach.
     for (auto it = cloudIn->begin(); it != cloudIn->end(); ++it)
     {
-      const auto pointDist = point_distance(*it, searchPoint);
+      const auto pointDist = pcl_tests::point_distance(*it, searchPoint);
       prioPointQueueEntry pointEntry (*it, pointDist, std::distance(cloudIn->begin(), it));
       pointCandidates.push (pointEntry);
     }
@@ -295,7 +287,7 @@ TEST (PCL, Organized_Neighbor_Search_Pointcloud_Neighbours_Within_Radius_Search)
     for (int ypos = -centerY; ypos < centerY; ypos++)
       for (int xpos = -centerX; xpos < centerX; xpos++)
       {
-        double z = 5.0 * ( ((double)rand () / (double)RAND_MAX))+5;
+        double z = 5.0 * ( (static_cast<double>(rand ()) / static_cast<double>(RAND_MAX)))+5;
         double y = ypos*oneOverFocalLength*z;
         double x = xpos*oneOverFocalLength*z;
         (*cloudIn)[idx++]= PointXYZ (x, y, z);
@@ -305,21 +297,21 @@ TEST (PCL, Organized_Neighbor_Search_Pointcloud_Neighbours_Within_Radius_Search)
 
     const PointXYZ& searchPoint = (*cloudIn)[randomIdx];
 
-    const double searchRadius = 1.0 * ((double)rand () / (double)RAND_MAX);
+    const double searchRadius = 1.0 * (static_cast<double>(rand ()) / static_cast<double>(RAND_MAX));
     //   double searchRadius = 1/10;
 
     // bruteforce radius search
-    std::vector<int> cloudSearchBruteforce;
-    cloudSearchBruteforce.clear();
+    std::size_t cloudSearchBruteforce_size_lower = 0, cloudSearchBruteforce_size_upper = 0;
 
-    for (auto it = cloudIn->points.cbegin(); it != cloudIn->points.cend(); ++it)
+    for (const auto& point : cloudIn->points)
     {
-      const auto pointDist = point_distance(*it, searchPoint);
+      const auto pointDist = pcl_tests::point_distance(point, searchPoint);
 
-      if (pointDist <= searchRadius)
-      {
-        // add point candidates to vector list
-        cloudSearchBruteforce.push_back (std::distance(cloudIn->points.cbegin(), it));
+      if (pointDist <= (searchRadius+TOLERANCE)) {
+        ++cloudSearchBruteforce_size_upper;
+        if (pointDist <= (searchRadius-TOLERANCE)) {
+          ++cloudSearchBruteforce_size_lower;
+        }
       }
     }
 
@@ -331,22 +323,15 @@ TEST (PCL, Organized_Neighbor_Search_Pointcloud_Neighbours_Within_Radius_Search)
     organizedNeighborSearch.radiusSearch ((*cloudIn)[randomIdx], searchRadius, cloudNWRSearch, cloudNWRRadius, std::numeric_limits<unsigned int>::max());
 
 
-    // check if result from organized radius search can be also found in bruteforce search
+    // check if results from organized radius search are indeed within the search radius
     for (const auto it : cloudNWRSearch)
     {
-      const auto pointDist = point_distance((*cloudIn)[it], searchPoint);
-      ASSERT_LE (pointDist, searchRadius);
+      const auto pointDist = pcl_tests::point_distance((*cloudIn)[it], searchPoint);
+      ASSERT_LE (pointDist, (searchRadius+TOLERANCE));
     }
 
-
-    // check if bruteforce result from organized radius search can be also found in bruteforce search
-    for (const auto it : cloudSearchBruteforce)
-    {
-      const auto pointDist = point_distance((*cloudIn)[it], searchPoint);
-      ASSERT_LE (pointDist, searchRadius);
-    }
-
-    ASSERT_EQ (cloudNWRRadius.size() , cloudSearchBruteforce.size ());
+    ASSERT_GE (cloudNWRRadius.size() , cloudSearchBruteforce_size_lower);
+    ASSERT_LE (cloudNWRRadius.size() , cloudSearchBruteforce_size_upper);
 
     // check if result limitation works
     organizedNeighborSearch.radiusSearch (searchPoint, searchRadius, cloudNWRSearch, cloudNWRRadius, 5);
@@ -355,90 +340,6 @@ TEST (PCL, Organized_Neighbor_Search_Pointcloud_Neighbours_Within_Radius_Search)
   }
 }
 
-
-TEST (PCL, Organized_Neighbor_Search_Pointcloud_Neighbours_Within_Radius_Search_Benchmark_Test)
-{
-  constexpr unsigned int test_runs = 10;
-  const unsigned int seed = time (nullptr);
-  srand (seed);
-
-  search::OrganizedNeighbor<PointXYZ> organizedNeighborSearch;
-
-  std::vector<int> k_indices;
-  std::vector<float> k_sqr_distances;
-
-  std::vector<int> k_indices_bruteforce;
-  std::vector<float> k_sqr_distances_bruteforce;
-
-  // typical focal length from kinect
-  constexpr double oneOverFocalLength = 0.0018;
-
-  double radiusSearchTime = 0, radiusSearchLPTime = 0;
-
-  for (unsigned int test_id = 0; test_id < test_runs; test_id++)
-  {
-    // generate point cloud
-
-    PointCloud<PointXYZ>::Ptr cloudIn (new PointCloud<PointXYZ> ());
-
-    cloudIn->width = 1024;
-    cloudIn->height = 768;
-    cloudIn->points.clear();
-    cloudIn->points.resize (cloudIn->width * cloudIn->height);
-
-    int centerX = cloudIn->width >> 1;
-    int centerY = cloudIn->height >> 1;
-
-    int idx = 0;
-    for (int ypos = -centerY; ypos < centerY; ypos++)
-      for (int xpos = -centerX; xpos < centerX; xpos++)
-      {
-        double z = 5.0 * ( ((double)rand () / (double)RAND_MAX))+5;
-        double y = ypos*oneOverFocalLength*z;
-        double x = xpos*oneOverFocalLength*z;
-
-        (*cloudIn)[idx++]= PointXYZ (x, y, z);
-      }
-
-    const unsigned int randomIdx = rand() % (cloudIn->width * cloudIn->height);
-
-    const PointXYZ& searchPoint = (*cloudIn)[randomIdx];
-
-    const double searchRadius = 1.0 * ((double)rand () / (double)RAND_MAX);
-
-    // bruteforce radius search
-    std::vector<int> cloudSearchBruteforce;
-    cloudSearchBruteforce.clear();
-
-    for (auto it = cloudIn->points.cbegin(); it != cloudIn->points.cend(); ++it)
-    {
-      const auto pointDist = point_distance(*it, searchPoint);
-
-      if (pointDist <= searchRadius)
-      {
-        // add point candidates to vector list
-        cloudSearchBruteforce.push_back (std::distance(cloudIn->points.cbegin(), it));
-      }
-    }
-
-    pcl::Indices cloudNWRSearch;
-    std::vector<float> cloudNWRRadius;
-
-    double check_time = getTime();
-    organizedNeighborSearch.setInputCloud (cloudIn);
-    organizedNeighborSearch.radiusSearch ((*cloudIn)[randomIdx], searchRadius, cloudNWRSearch, cloudNWRRadius, std::numeric_limits<unsigned int>::max());
-
-    double check_time2 = getTime();
-
-    radiusSearchLPTime += check_time2 - check_time;
-
-    organizedNeighborSearch.setInputCloud (cloudIn);
-    organizedNeighborSearch.radiusSearch ((*cloudIn)[randomIdx], searchRadius, cloudNWRSearch, cloudNWRRadius, std::numeric_limits<unsigned int>::max());
-
-    radiusSearchTime += getTime() - check_time2;
-  }
-}
-
 TEST (PCL, Organized_Neighbor_Search_Pointcloud_Neighbours_Within_Radius_Search_Kinect_Data)
 {
 
@@ -523,36 +424,29 @@ TEST (PCL, Organized_Neighbor_Search_Pointcloud_Neighbours_Within_Radius_Search_
     const PointXYZ& searchPoint = (*cloudIn)[randomIdx];
 
     // bruteforce radius search
-    std::vector<int> cloudSearchBruteforce;
-    cloudSearchBruteforce.clear();
+    std::size_t cloudSearchBruteforce_size_lower = 0, cloudSearchBruteforce_size_upper = 0;
 
-    for (auto it = cloudIn->points.cbegin(); it != cloudIn->points.cend(); ++it)
+    for (const auto& point : cloudIn->points)
     {
-      const auto pointDist = point_distance(*it, searchPoint);
+      const auto pointDist = pcl_tests::point_distance(point, searchPoint);
 
-      if (pointDist <= searchRadius)
-      {
-        // add point candidates to vector list
-        cloudSearchBruteforce.push_back (std::distance(cloudIn->points.cbegin(), it));
+      if (pointDist <= (searchRadius+TOLERANCE)) {
+        ++cloudSearchBruteforce_size_upper;
+        if (pointDist <= (searchRadius-TOLERANCE)) {
+          ++cloudSearchBruteforce_size_lower;
+        }
       }
     }
 
-    // check if result from organized radius search can be also found in bruteforce search
+    // check if results from organized radius search are indeed within the search radius
     for (const auto it : cloudNWRSearch)
     {
-      const auto pointDist = point_distance((*cloudIn)[it], searchPoint);
-      ASSERT_LE (pointDist, searchRadius);
+      const auto pointDist = pcl_tests::point_distance((*cloudIn)[it], searchPoint);
+      ASSERT_LE (pointDist, (searchRadius+TOLERANCE));
     }
 
-
-    // check if bruteforce result from organized radius search can be also found in bruteforce search
-    for (const auto it : cloudSearchBruteforce)
-    {
-      const auto pointDist = point_distance((*cloudIn)[it], searchPoint);
-      ASSERT_LE (pointDist, searchRadius);
-    }
-
-    ASSERT_EQ (cloudNWRRadius.size() , cloudSearchBruteforce.size ());
+    ASSERT_GE (cloudNWRRadius.size() , cloudSearchBruteforce_size_lower);
+    ASSERT_LE (cloudNWRRadius.size() , cloudSearchBruteforce_size_upper);
 
     // check if result limitation works
     organizedNeighborSearch.radiusSearch (searchPoint, searchRadius, cloudNWRSearch, cloudNWRRadius, 5);
