@@ -84,7 +84,7 @@ loadTrainedFeatures (std::vector<FeatureT::Ptr> &out,
   for (boost::filesystem::directory_iterator it (base_dir); it != boost::filesystem::directory_iterator (); ++it)
   {    
     if (!boost::filesystem::is_directory (it->status ()) &&
-        boost::filesystem::extension (it->path ()) == ".pcd")
+        it->path ().extension ().string () == ".pcd")
     {   
       const std::string path = it->path ().string ();
 
