@@ -64,7 +64,7 @@
 #include <vtkMath.h>
 
 #include <boost/algorithm/string.hpp>  // for boost::is_any_of, boost::split, boost::token_compress_on, boost::trim
-#include <boost/filesystem.hpp>  // for boost::filesystem::create_directories, boost::filesystem::exists, boost::filesystem::extension, boost::filesystem::path
+#include <boost/filesystem.hpp>  // for boost::filesystem::create_directories, boost::filesystem::exists, boost::filesystem::path, boost::filesystem::path::extension
 
 using namespace pcl;
 
@@ -87,7 +87,7 @@ struct ScanParameters
 vtkPolyData*
 loadDataSet (const char* file_name)
 {
-  std::string extension = boost::filesystem::extension (file_name);
+  std::string extension = boost::filesystem::path (file_name).extension ().string ();
   if (extension == ".ply")
   {
     vtkPLYReader* reader = vtkPLYReader::New ();
@@ -255,7 +255,6 @@ main (int argc, char** argv)
   if (single_view)
     number_of_points = 1;
 
-  int sid = -1;
   for (int i = 0; i < number_of_points; i++)
   {
     // Clear cloud for next view scan
@@ -334,18 +333,13 @@ main (int argc, char** argv)
     // Sweep vertically
     for (double vert = vert_start; vert <= vert_end; vert += sp.vert_res)
     {
-      sid++;
-
       tr1->Identity ();
       tr1->RotateWXYZ (vert, right);
       tr1->InternalTransformPoint (viewray, temp_beam);
 
       // Sweep horizontally
-      int pid = -1;
       for (double hor = hor_start; hor <= hor_end; hor += sp.hor_res)
       {
-        pid ++;
-
         // Create a beam vector with (lat,long) angles (vert, hor) with the viewray
         tr2->Identity ();
         tr2->RotateWXYZ (hor, up);
