@@ -14,10 +14,9 @@ NormalCoherence<PointInT>::computeCoherence(PointInT& source, PointInT& target)
   Eigen::Vector4f n = source.getNormalVector4fMap();
   Eigen::Vector4f n_dash = target.getNormalVector4fMap();
   if (n.norm() <= 1e-5 || n_dash.norm() <= 1e-5) {
-    PCL_ERROR("norm might be ZERO!\n");
-    std::cout << "source: " << source << std::endl;
-    std::cout << "target: " << target << std::endl;
-    exit(1);
+    PCL_ERROR_STREAM("[NormalCoherence::computeCoherence] normal of source and/or "
+                     "target is zero! source: "
+                     << source << "target: " << target << std::endl);
     return 0.0;
   }
   n.normalize();
