@@ -77,7 +77,7 @@ namespace pcl
         {}
 
         /** \brief Destructor. */
-        virtual ~PointCloudGeometryHandler () {}
+        virtual ~PointCloudGeometryHandler() = default;
 
         /** \brief Abstract getName method.
           * \return the name of the class/object.
@@ -89,7 +89,7 @@ namespace pcl
         virtual std::string
         getFieldName () const  = 0;
 
-        /** \brief Checl if this handler is capable of handling the input data or not. */
+        /** \brief Check if this handler is capable of handling the input data or not. */
         inline bool
         isCapable () const { return (capable_); }
 
@@ -150,9 +150,6 @@ namespace pcl
         /** \brief Constructor. */
         PointCloudGeometryHandlerXYZ (const PointCloudConstPtr &cloud);
 
-        /** \brief Destructor. */
-        virtual ~PointCloudGeometryHandlerXYZ () {};
-
         /** \brief Class getName method. */
         virtual std::string
         getName () const { return ("PointCloudGeometryHandlerXYZ"); }
@@ -343,7 +340,7 @@ namespace pcl
         }
 
         /** \brief Destructor. */
-        virtual ~PointCloudGeometryHandler () {}
+        virtual ~PointCloudGeometryHandler() = default;
 
         /** \brief Abstract getName method. */
         virtual std::string
@@ -414,9 +411,6 @@ namespace pcl
         /** \brief Constructor. */
         PointCloudGeometryHandlerXYZ (const PointCloudConstPtr &cloud);
 
-        /** \brief Destructor. */
-        virtual ~PointCloudGeometryHandlerXYZ () {}
-
         /** \brief Class getName method. */
         virtual std::string 
         getName () const { return ("PointCloudGeometryHandlerXYZ"); }
@@ -477,9 +471,6 @@ namespace pcl
                                          const std::string &y_field_name,
                                          const std::string &z_field_name);
 
-        /** \brief Destructor. */
-        virtual ~PointCloudGeometryHandlerCustom () {}
-
         /** \brief Class getName method. */
         virtual std::string
         getName () const { return ("PointCloudGeometryHandlerCustom"); }
